@@ -145,10 +145,12 @@ class IBMCloudAccess:
 
     @property
     def cos_session(self):
+        """Get the current COS session."""
         return self._session
 
     @property
     def thread_safe(self):
+        """Check if SQLQuery is in thread-safe mode."""
         return self._thread_safe
 
     def get_session(self):
@@ -216,8 +218,7 @@ class IBMCloudAccess:
         return ibm_boto3._get_default_session()
 
     def logon(self, force=False, token=None):
-        """
-        Establish a connection to IBM Cloud
+        """Establish a connection to IBM Cloud.
 
         Parameters
         -----------
